@@ -167,15 +167,14 @@ metricsEndpointMiddleware MetricsEndpoint {..} =
         sampleWithCache = case mCache of
           Nothing -> metricsEndpointSample
           Just (cacheDurationNanos, var) -> do
-            modifyMVar var $ \lastTup@(lastSampleTime, lastSample) -> do
-              now <- getMonotonicTimeNSec
+            now <- getMonotonicTimeNSec
+            modifyMVar var $ \lastTup@(lastSampleTime, lastSample) ->
               if now - lastSampleTime < cacheDurationNanos
                 then pure (lastTup, lastSample)
                 else do
-                  newSample <- metricsEndpointSample
-                  let combinedSample = combineRegistrySample lastSample newSample
-                  let newTup = (now, combinedSample)
-                  pure (newTup, combinedSample)
+                  freshSample <- metricsEndpointSample
+                  let freshTup = (now, freshSample)
+                  pure (freshTup, freshSample)
 
     pure $ \application request sendResponse ->
       if Request.rawPathInfo request == metricsEndpointPath
